@@ -8,7 +8,7 @@ def normalize_html_text(text: str) -> str:
     if text is not None:
         t = text.strip()
         t = nm('NFKC', t) # 去除一下 x34 类似的特殊字符
-        t = t.replace(' ', '')
+        t = t.replace('\n\t', '')
         t = t.replace('\n', '')
         t = re.sub('^[\[][1-9]*[\]]$', '', t) # 去除[12]这样的标签
         return t
